import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Button, Stack, Text } from '@chakra-ui/react';
import { saveNetworkStatus } from '../save-network-status.js';
import { useContainer } from '../hooks/use-container.js';
import { useNetworkStatus } from '../hooks/use-network-status.js';
import { useCurrentStatus } from '../hooks/use-current-status.js';
/**
 * React component that manages network state.
 * @param {DeepClient} deep - The DeepClient object instance.
 */
export function NetworkStatus({ deep }) {
    const containerLinkId = useContainer(deep); // Get the container's link ID using deep client instance.
    const { connectionStatuses, subscribeToNetworkStatusChanges } = useNetworkStatus({ deep, containerLinkId });
    // Get the current network status and a function to subscribe to network status changes.
    const { currentStatus, loadCurrentStatus } = useCurrentStatus({ deep, containerLinkId });
    // Get the current network status and a function to load it.
    /**
     * Render function that returns a stack layout UI with two buttons: one for subscribing to network changes and another one for saving the current network state.
     * It also displays all connection statuses existing in the local store variable connectionStatuses.
     */
    return (_jsxs(Stack, { children: [_jsx(Text, { size: "lg", children: "NETWORK STATE" }), _jsx(Button, { onClick: async () => {
                    await subscribeToNetworkStatusChanges();
                }, children: _jsx(Text, { children: "SUBSCRIBE" }) }), _jsx(Button, { onClick: async () => await saveNetworkStatus({ deep, containerLinkId, connectionStatuses: [] }), children: _jsx(Text, { children: "SAVE CURRENT" }) }), _jsx(Button, { onClick: async () => loadCurrentStatus(), children: _jsx(Text, { children: "GET CURRENT" }) }), currentStatus ?
                (_jsxs(Stack, { direction: "row", children: [_jsx(Text, { children: "CURRENT:" }), _jsx(Text, { children: currentStatus })] }))
                : null] }));
}
